"use strict";

var Reflux = require("reflux");
var _ = require("lodash");
var DashboardActions = require("./../actions/DashboardActions");

var _dashboards = [];
var _currentIndex = 0;

var DashboardStore = Reflux.createStore({
    init: function init() {
        this.listenTo(DashboardActions.setDashboards, this.setDashboards);
        this.listenTo(DashboardActions.previousDashboard, this.previousDashboard);
        this.listenTo(DashboardActions.nextDashboard, this.nextDashboard);
        this.listenTo(DashboardActions.startRotation, this.startRotation);
    },

    startRotation: function startRotation() {
        var _this = this;
        setInterval(function () {
            _this.nextDashboard();
        }, 4000);
    },

    previousDashboard: function previousDashboard() {
        _currentIndex--;
        this.trigger(_currentIndex);
    },

    nextDashboard: function nextDashboard() {
        if (_currentIndex < _dashboards.length - 1) {
            _currentIndex++;
        } else {
            _currentIndex = 0;
        }

        this.trigger(_currentIndex);
    },

    setDashboards: function setDashboards(dashboards) {
        _.forEach(dashboards, function (dashboard, index) {
            dashboard.index = index;
        });

        _dashboards = dashboards;
        _currentIndex = 0;

        this.trigger(_currentIndex);
    },

    currentIndex: function currentIndex() {
        return _currentIndex;
    }
});

module.exports = DashboardStore;